@@ -7,19 +7,16 @@ from inspect import cleandoc
 import pytest
 
 import jedi
-from jedi import __doc__ as jedi_doc, names
-from ..helpers import TestCase
+from jedi import __doc__ as jedi_doc
 from jedi.evaluate.compiled import CompiledContextName
 
 
 def test_is_keyword(Script):
-    #results = Script('import ', 1, 1, None).goto_definitions()
-    #assert len(results) == 1 and results[0].is_keyword is True
     results = Script('str', 1, 1, None).goto_definitions()
     assert len(results) == 1 and results[0].is_keyword is False
 
 
-def test_basedefinition_type(Script, environment):
+def test_basedefinition_type(Script, names):
     def make_definitions():
         """
         Return a list of definitions for parametrized tests.
@@ -44,7 +41,7 @@ def test_basedefinition_type(Script, environment):
         """)
 
         definitions = []
-        definitions += names(source, environment=environment)
+        definitions += names(source)
 
         source += dedent("""
         variable = sys or C or x or f or g or g() or h""")
@@ -102,8 +99,8 @@ def test_function_call_signature_in_doc(Script):
     assert "f(x, y=1, z='a')" in str(doc)
 
 
-def test_param_docstring():
-    param = jedi.names("def test(parameter): pass", all_scopes=True)[1]
+def test_param_docstring(names):
+    param = names("def test(parameter): pass", all_scopes=True)[1]
     assert param.name == 'parameter'
     assert param.docstring() == ''
 
@@ -140,28 +137,32 @@ def test_completion_docstring(Script, jedi_path):
 
     docstr('abcd=3;abcd', '')
     docstr('"hello"\nabcd=3\nabcd', '')
-    docstr(dedent('''
+    docstr(
+        dedent('''
         def x():
             "hello"
             0
         x'''),
         'hello'
     )
-    docstr(dedent('''
+    docstr(
+        dedent('''
         def x():
             "hello";0
         x'''),
         'hello'
     )
     # Shouldn't work with a tuple.
-    docstr(dedent('''
+    docstr(
+        dedent('''
         def x():
             "hello",0
         x'''),
         ''
     )
     # Should also not work if we rename something.
-    docstr(dedent('''
+    docstr(
+        dedent('''
         def x():
             "hello"
         y = x
@@ -216,75 +217,61 @@ def test_param_endings(Script):
     assert [p.description for p in sig.params] == ['param a', 'param b=5', 'param c=""']
 
 
-class TestIsDefinition(TestCase):
-    @pytest.fixture(autouse=True)
-    def init(self, environment):
-        self.environment = environment
-
-    def _def(self, source, index=-1):
-        return names(
-            dedent(source),
-            references=True,
-            all_scopes=True,
-            environment=self.environment
-        )[index]
-
-    def _bool_is_definitions(self, source):
-        ns = names(dedent(source), references=True, all_scopes=True)
-        # Assure that names are definitely sorted.
-        ns = sorted(ns, key=lambda name: (name.line, name.column))
-        return [name.is_definition() for name in ns]
-
-    def test_name(self):
-        d = self._def('name')
-        assert d.name == 'name'
-        assert not d.is_definition()
-
-    def test_stmt(self):
-        src = 'a = f(x)'
-        d = self._def(src, 0)
-        assert d.name == 'a'
-        assert d.is_definition()
-        d = self._def(src, 1)
-        assert d.name == 'f'
-        assert not d.is_definition()
-        d = self._def(src)
-        assert d.name == 'x'
-        assert not d.is_definition()
-
-    def test_import(self):
-        assert self._bool_is_definitions('import x as a') == [False, True]
-        assert self._bool_is_definitions('from x import y') == [False, True]
-        assert self._bool_is_definitions('from x.z import y') == [False, False, True]
+@pytest.mark.parametrize(
+    'code, index, name, is_definition', [
+        ('name', 0, 'name', False),
+        ('a = f(x)', 0, 'a', True),
+        ('a = f(x)', 1, 'f', False),
+        ('a = f(x)', 2, 'x', False),
+    ]
+)
+def test_is_definition(names, code, index, name, is_definition):
+    d = names(
+        dedent(code),
+        references=True,
+        all_scopes=True,
+    )[index]
+    assert d.name == name
+    assert d.is_definition() == is_definition
 
 
-class TestParent(TestCase):
-    @pytest.fixture(autouse=True)
-    def init(self, Script):
-        self.Script = Script
+@pytest.mark.parametrize(
+    'code, expected', (
+        ('import x as a', [False, True]),
+        ('from x import y', [False, True]),
+        ('from x.z import y', [False, False, True]),
+    )
+)
+def test_is_definition_import(names, code, expected):
+    ns = names(dedent(code), references=True, all_scopes=True)
+    # Assure that names are definitely sorted.
+    ns = sorted(ns, key=lambda name: (name.line, name.column))
+    assert [name.is_definition() for name in ns] == expected
 
-    def _parent(self, source, line=None, column=None):
-        def_, = self.Script(dedent(source), line, column).goto_assignments()
+
+def test_parent(Script):
+    def _parent(source, line=None, column=None):
+        def_, = Script(dedent(source), line, column).goto_assignments()
         return def_.parent()
 
-    def test_parent(self):
-        parent = self._parent('foo=1\nfoo')
-        assert parent.type == 'module'
+    parent = _parent('foo=1\nfoo')
+    assert parent.type == 'module'
 
-        parent = self._parent('''
-            def spam():
-                if 1:
-                    y=1
-                    y''')
-        assert parent.name == 'spam'
-        assert parent.parent().type == 'module'
+    parent = _parent('''
+        def spam():
+            if 1:
+                y=1
+                y''')
+    assert parent.name == 'spam'
+    assert parent.parent().type == 'module'
 
-    def test_on_function(self):
-        parent = self._parent('''\
-            def spam():
-                pass''', 1, len('def spam'))
-        assert parent.name == ''
-        assert parent.type == 'module'
+
+def test_parent_on_function(Script):
+    code = 'def spam():\n pass'
+    def_, = Script(code, line=1, column=len('def spam')).goto_assignments()
+    parent = def_.parent()
+    assert parent.name == ''
+    assert parent.type == 'module'
 
 
 def test_parent_on_completion(Script):
@@ -331,8 +318,8 @@ different as an implementation.
 """
 
 
-def test_goto_assignment_repetition(environment):
-    defs = names('a = 1; a', references=True, definitions=False, environment=environment)
+def test_goto_assignment_repetition(names):
+    defs = names('a = 1; a', references=True, definitions=False)
     # Repeat on the same variable. Shouldn't change once we're on a
     # definition.
     for _ in range(3):
@@ -341,34 +328,34 @@ def test_goto_assignment_repetition(environment):
         assert ass[0].description == 'a = 1'
 
 
-def test_goto_assignments_named_params(environment):
+def test_goto_assignments_named_params(names):
     src = """\
             def foo(a=1, bar=2):
                 pass
             foo(bar=1)
           """
-    bar = names(dedent(src), references=True, environment=environment)[-1]
+    bar = names(dedent(src), references=True)[-1]
     param = bar.goto_assignments()[0]
     assert (param.line, param.column) == (1, 13)
     assert param.type == 'param'
 
 
-def test_class_call(environment):
+def test_class_call(names):
     src = 'from threading import Thread; Thread(group=1)'
-    n = names(src, references=True, environment=environment)[-1]
+    n = names(src, references=True)[-1]
     assert n.name == 'group'
     param_def = n.goto_assignments()[0]
     assert param_def.name == 'group'
     assert param_def.type == 'param'
 
 
-def test_parentheses(environment):
-    n = names('("").upper', references=True, environment=environment)[-1]
+def test_parentheses(names):
+    n = names('("").upper', references=True)[-1]
     assert n.goto_assignments()[0].name == 'upper'
 
 
-def test_import(environment):
-    nms = names('from json import load', references=True, environment=environment)
+def test_import(names):
+    nms = names('from json import load', references=True)
     assert nms[0].name == 'json'
     assert nms[0].type == 'module'
     n = nms[0].goto_assignments()[0]
@@ -381,7 +368,7 @@ def test_import(environment):
     assert n.name == 'load'
     assert n.type == 'function'
 
-    nms = names('import os; os.path', references=True, environment=environment)
+    nms = names('import os; os.path', references=True)
     assert nms[0].name == 'os'
     assert nms[0].type == 'module'
     n = nms[0].goto_assignments()[0]
@@ -392,7 +379,7 @@ def test_import(environment):
     assert n.name == 'path'
     assert n.type == 'module'
 
-    nms = names('import os.path', references=True, environment=environment)
+    nms = names('import os.path', references=True)
     n = nms[0].goto_assignments()[0]
     assert n.name == 'os'
     assert n.type == 'module'
@@ -403,8 +390,8 @@ def test_import(environment):
     assert n.type == 'module'
 
 
-def test_import_alias(environment):
-    nms = names('import json as foo', references=True, environment=environment)
+def test_import_alias(names):
+    nms = names('import json as foo', references=True)
     assert nms[0].name == 'json'
     assert nms[0].type == 'module'
     assert nms[0]._name.tree_name.parent.type == 'dotted_as_name'
@@ -455,3 +442,20 @@ def test_builtin_module_with_path(Script):
     assert semlock.name == 'SemLock'
     assert semlock.line is None
     assert semlock.column is None
+
+
+@pytest.mark.parametrize(
+    'code, description', [
+        ('int', 'instance int'),
+        ('str.index', 'instance int'),
+        ('1', None),
+    ]
+)
+def test_execute(Script, code, description):
+    definition, = Script(code).goto_assignments()
+    definitions = definition.execute()
+    if description is None:
+        assert not definitions
+    else:
+        d, = definitions
+        assert d.description == description
